# simproktools

```simproktools``` is a small library consisting of useful machines for [simprokmachine](https://github.com/simprok-dev/simprokmachine-flutter) framework. 

# Installation

Add the line into pubspec.yaml:

```
dependencies:
    simproktools: ^1.0.0
```

Now in your Dart code, you can use:


```Dart
import 'package:simproktools/simproktools.dart';
```

# JustMachine

A machine that accepts a value which is passed back into the callback every time an event is received.

```Dart

final Machine<Input, int> _ = JustMachine(value: 0); // int can be replaced with any type
```


# SingleMachine

A machine that accepts a value which is passed back into the callback *THE FIRST* time an event is received.

```Dart

final Machine<Input, int> _ = SingleMachine(value: 0); // int can be replaced with any type
```

# ValueMachine

A machine that accepts a value as an input and immediately passes it back into the callback as an output.

```Dart

final Machine<T, T> _ = ValueMachine();
```

# NeverMachine

A machine that accepts an input and ignores it never passing back any output.

```Dart

final Machine<Input, Output> _ = NeverMachine();
```

# ReducerMachine

A machine with an Input being an Event and an Output being a State. 

It accepts an initial State value(or not, in which case it is nil by default) and a function that accepts a current State and a new Event and returns a new State. Every time an Input is received by the machine it triggers the reducer and passes a new State into an Output callback. 

```Dart

// bool and Int can be replaced with any types

final Machine<bool, int> _ = ReducerMachine.create(
    initial: 0,
    reducer: (int state, bool value) => 0, // 0 will be a new State and will be passed as an Output 
);
// or

// bool and Int can be replaced with any types
final Machine<bool, int> _ = ReducerMachine.createNullInitial((int? state, bool value) => 0); // 0 will be a new State and will be passed as an Output 


```

# LogMachine

A machine that prints an Input every time it is received and never triggers an Output callback.

```Dart

final Machine<Input, Output> _ = LogMachine() 
```
